import dotenv from "dotenv";
import express from "express";
import cors from "cors";

import authRoutes from "./routes/auth.js";
import recipeRoutes from "./routes/recipes.js";
import userRoutes from "./routes/users.js";

dotenv.config();

const app = express();
const PORT = process.env.PORT || 3000;

// Middleware
app.use(cors());
app.use(express.json());
app.use(express.urlencoded({ extended: true }));

// Routes
app.use("/auth", authRoutes);
app.use("/recipes", recipeRoutes);
app.use("/users", userRoutes);

// Fallback Route
app.get("/", (req, res) => {
  res.send("Welcome to the Hub-Site backend API!");
});

// Server
app.listen(PORT, () => {
  console.log(`Server running on http://localhost:${PORT}`);
});

